pub fn build_path_entry(
path: &Path,
with_lines: bool,
) -> (PathEntry, SystemTime)Expand description
Build a normalized filesystem entry for tool output. Returns the entry plus raw mtime for optional sorting.
pub fn build_path_entry(
path: &Path,
with_lines: bool,
) -> (PathEntry, SystemTime)Build a normalized filesystem entry for tool output. Returns the entry plus raw mtime for optional sorting.