pub struct FilesystemEntriesOutput {
pub items: Vec<PathEntry>,
pub truncated: Option<TruncationMeta>,
}Fields
items: Vec<PathEntry>truncated: Option<TruncationMeta>Trait Implementations
Sourceimpl Clone for FilesystemEntriesOutput
impl Clone for FilesystemEntriesOutput
Sourcefn clone(&self) -> FilesystemEntriesOutput
fn clone(&self) -> FilesystemEntriesOutput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FilesystemEntriesOutput
impl Debug for FilesystemEntriesOutput
Sourceimpl JsonSchema for FilesystemEntriesOutput
impl JsonSchema for FilesystemEntriesOutput
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FilesystemEntriesOutput
impl RefUnwindSafe for FilesystemEntriesOutput
impl Send for FilesystemEntriesOutput
impl Sync for FilesystemEntriesOutput
impl Unpin for FilesystemEntriesOutput
impl UnsafeUnpin for FilesystemEntriesOutput
impl UnwindSafe for FilesystemEntriesOutput