pub struct PathEntry {
pub path: String,
pub kind: String,
pub size_bytes: u64,
pub lines: Option<u64>,
pub modified_at: String,
}Fields
path: Stringkind: Stringsize_bytes: u64lines: Option<u64>modified_at: StringTrait Implementations
Sourceimpl JsonSchema for PathEntry
impl JsonSchema for PathEntry
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PathEntry
impl RefUnwindSafe for PathEntry
impl Send for PathEntry
impl Sync for PathEntry
impl Unpin for PathEntry
impl UnsafeUnpin for PathEntry
impl UnwindSafe for PathEntry