pub struct TruncationMeta {
pub shown: usize,
pub total: usize,
pub omitted: usize,
}Fields
shown: usizetotal: usizeomitted: usizeTrait Implementations
Sourceimpl Clone for TruncationMeta
impl Clone for TruncationMeta
Sourcefn clone(&self) -> TruncationMeta
fn clone(&self) -> TruncationMeta
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TruncationMeta
impl Debug for TruncationMeta
Sourceimpl JsonSchema for TruncationMeta
impl JsonSchema for TruncationMeta
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TruncationMeta
impl RefUnwindSafe for TruncationMeta
impl Send for TruncationMeta
impl Sync for TruncationMeta
impl Unpin for TruncationMeta
impl UnsafeUnpin for TruncationMeta
impl UnwindSafe for TruncationMeta