pub struct StaticToolProvider<E: StaticToolExecute> { /* private fields */ }Expand description
A ToolProvider that serves a fixed set of ToolDefinitions from a
cache, delegating execution to an StaticToolExecute.
Implementations
Sourceimpl<E: StaticToolExecute> StaticToolProvider<E>
impl<E: StaticToolExecute> StaticToolProvider<E>
Sourcepub fn new(definitions: Vec<ToolDefinition>, executor: E) -> Self
pub fn new(definitions: Vec<ToolDefinition>, executor: E) -> Self
Build a provider from a fixed set of definitions and an executor.
Manifests and contracts are derived once, here, and reused for the life of the provider.